@@ -1,6 +1,6 @@
 /* -*- c++ -*- */
 /*
- * Copyright 2004 Free Software Foundation, Inc.
+ * Copyright 2004,2006 Free Software Foundation, Inc.
  * 
  * This file is part of GNU Radio
  * 
@@ -31,7 +31,9 @@ class audio_oss_source;
 typedef boost::shared_ptr<audio_oss_source> audio_oss_source_sptr;
 
 audio_oss_source_sptr
-audio_oss_make_source (int sampling_freq, const std::string dev = "");
+audio_oss_make_source (int sampling_rate,
+		       const std::string dev = "",
+		       bool ok_to_block = true);
 
 /*!
  * \brief audio source using OSS
@@ -42,23 +44,25 @@ audio_oss_make_source (int sampling_freq, const std::string dev = "");
 
 class audio_oss_source : public gr_sync_block {
   friend audio_oss_source_sptr
-  audio_oss_make_source (int sampling_freq, const std::string device_name);
+  audio_oss_make_source (int sampling_rate, const std::string device_name, bool ok_to_block);
 
-  int		d_sampling_freq;
+  int		d_sampling_rate;
   std::string	d_device_name;
   int		d_fd;
   short	       *d_buffer;
   int		d_chunk_size;
 
  protected:
-  audio_oss_source (int sampling_freq, const std::string device_name = "");
+  audio_oss_source (int sampling_rate,
+		    const std::string device_name = "",
+		    bool ok_to_block = true);
 
  public:
   ~audio_oss_source ();
   
   int work (int noutput_items,
-		  gr_vector_const_void_star &input_items,
-		  gr_vector_void_star &output_items);
+	    gr_vector_const_void_star &input_items,
+	    gr_vector_void_star &output_items);
 };
 
 
